#### Please select the sections that you would like to print

Select All
Case Information
Party
Disposition Events
Events and Hearings
Print

# Case Information

19CV000014 | Cryrag, Inc. vs Ricardo Lemus et al

Case Number
19CV000014

Court
Superior Court of Napa - Civil

File Date
01/03/2019

Case Type
Unlawful Detainer Residential Limited (32) - under 10,000

Case Status
Inactive

# Party

Plaintiff
Cryrag, Inc.

Active Attorneys

Lead Attorney
Myers, Alexander James

Retained

Work Phone
707-257-1185

Defendant
Lemus, Ricardo

Address

39 Coombs ST
Napa CA 94559

Active Attorneys

Pro Se

Defendant
Patsias, Athanasia

Address

39 Coombs ST
Napa CA 94559

Active Attorneys

Pro Se

# Disposition Events

02/08/2019 Judgment

Judgment Type
Judgment - Court Finding

Party
| Names: Cryrag, Inc. Lemus, Ricardo Patsias, Athanasia

# Events and Hearings

- 01/03/2019 Civil Case Cover Sheet

- 01/03/2019 Complaint-Unlawful Detainer (Limited): Up to $10K

- 01/03/2019 Summons: Issued and Filed

- 01/03/2019 Unlawful Detainer - Defendant's Notice

- 01/03/2019 Notice of Hearing Court

- 01/03/2019 UD: Complaint Filed

- 01/08/2019 Answer (Limited): Up to $10K

- 01/09/2019 Fee Waiver Granted

- 01/09/2019 Fee Waiver Granted

- 01/23/2019 Proof of Service

- 01/23/2019 Proof of Service

- 01/23/2019 Proof of Service

- 01/23/2019 Request

  Comment
  to Set Case for Trial

- 01/23/2019 Notice of Hearing Court

- ﻿

  02/08/2019 Court Trial: Short Cause

  Judicial Officer
  Langhorne, Monique

  Hearing Time
  9:30 AM

  Result
  Heard

  Comment
  TE: 30 Minutes

- 02/08/2019 Judgment

- 02/08/2019 UD: Judgment Against All Def Within 60 Days

- 02/11/2019 Writ (Issued)

- 02/11/2019 Minute Order

- 02/11/2019 Writ (Filed)

- 02/11/2019 Writ (Issued)

  Comment
  POSSESSION ONLY Napa County

- 02/25/2019 Writ (Filed)

  Comment
  County of Napa

- ﻿

  03/01/2019 OSC: Court's Motion to Dismiss

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Cancel Reason
  Vacated